rm(list=ls(all=TRUE))
library(mvtnorm)
library(EMMIXskew)
library(mclust)
WD.PATH = paste(getwd(),"/data and software/",sep="")
source(paste(WD.PATH,'function/MFA.na.r',sep=""))
source(paste(WD.PATH,'function/MSNFA.na.r',sep=""))
source(paste(WD.PATH,'function/MSTFA.na.r',sep=""))

## scan data CKD
Data=matrix(scan(paste(WD.PATH,'data/ckd.txt',sep="")), ncol=12, byrow=T)
true.clus=as.numeric(Data[, 12])
X=Y.na=scale(Data[,-12])

## Mean imputation
p=ncol(Y.na)
na.posi = is.na(Y.na)  
xbar = colMeans(Y.na, na.rm = T)
for(i in 1:p)
{
  X[na.posi[,i],i] =xbar[i]
}

## MFA fitting  g=2 and q=2
mfa.init = mfa.init.para(X, g=2, q=2)
fit.mfa=MFA.na.ECM(Y.na, init.para = mfa.init, true.clus=true.clus, zero.mu = F, tol = 1e-3, max.iter=20000, per=100)

## MSNFA fitting  g=2 and q=2
msnfa.init = msnfa.init.para(X, g=2, q=2)
fit.msnfa = MSNFA.na.ECM(Y.na, init.para = msnfa.init, true.clus=true.clus, zero.mu = F, zero.la = F, tol = 1e-3, max.iter=20000, per=100)

## MSTFA fitting  g=2 and q=2
mstfa.init = mstfa.init.para(X, g=2, q=2)
fit.mstfa = MSNFA.na.ECM(Y.na, init.para = mstfa.init, true.clus=true.clus, zero.mu = F, zero.la = F, tol = 1e-3, max.iter=20000, per=100)
